@@ -62,7 +62,9 @@ Q_GADGET
             KindInputmethod,
             KindFirmware,
             KindDriver,
-            KindLocalization
+            KindLocalization,
+            KindService,
+            KindRepository
         };
         Q_ENUM(Kind)
 
@@ -80,7 +82,8 @@ Q_GADGET
             UrlKindFaq,
             UrlKindHelp,
             UrlKindDonation,
-            UrlTranslate
+            UrlTranslate,
+            UrlKindContact
         };
         Q_ENUM(UrlKind)
 
@@ -100,8 +103,11 @@ Q_GADGET
         Component(_AsComponent *cpt);
         Component();
         Component(const Component& other);
+        Component(Component&& other);
         ~Component();
 
+        Component& operator=(const Component& c);
+
         _AsComponent *asComponent() const;
 
         uint valueFlags() const;
